"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
function getConnectionOptions(logger) {
    if (!process.env.SLS_TYPEORM_MIGRATIONS_ENGINE) {
        logger("SLS_TYPEORM_MIGRATIONS_ENGINE environment variable required");
        process.exit(1);
    }
    if (!process.env.SLS_TYPEORM_MIGRATIONS_FOLDER) {
        logger("SLS_TYPEORM_MIGRATIONS_FOLDER environment variable required");
        process.exit(1);
    }
    if (!process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_URL &&
        (!process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_USERNAME ||
            !process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_PASSWORD ||
            !process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_NAME ||
            !process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_HOST ||
            !process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_PORT)) {
        logger("SLS_TYPEORM_MIGRATIONS_DATABASE_URL or [SLS_TYPEORM_MIGRATIONS_DATABASE_USERNAME, SLS_TYPEORM_MIGRATIONS_DATABASE_PASSWORD, SLS_TYPEORM_MIGRATIONS_DATABASE_NAME, SLS_TYPEORM_MIGRATIONS_DATABASE_HOST, SLS_TYPEORM_MIGRATIONS_DATABASE_PORT] environment variable required");
        process.exit(1);
    }
    var dbOptions = {};
    if (process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_URL) {
        dbOptions.url = process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_URL;
    }
    else {
        dbOptions.host = process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_HOST;
        dbOptions.port = parseInt(process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_PORT);
        dbOptions.database = process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_NAME;
        dbOptions.username = process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_USERNAME;
        dbOptions.password = Buffer.from(process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_PASSWORD, 'base64').toString('ascii');
    }
    return __assign({ type: process.env.SLS_TYPEORM_MIGRATIONS_ENGINE, url: process.env.SLS_TYPEORM_MIGRATIONS_DATABASE_URL, migrations: [process.env.SLS_TYPEORM_MIGRATIONS_FOLDER] }, dbOptions);
}
exports.getConnectionOptions = getConnectionOptions;
function logMigrations(logger, migrations) {
    if (typeof migrations !== "undefined" && (migrations === null || migrations === void 0 ? void 0 : migrations.length) > 0) {
        migrations === null || migrations === void 0 ? void 0 : migrations.forEach(function (migration) { return logger("Migrated: " + migration.name); });
    }
    else {
        logger("No new migrations to run");
    }
}
exports.logMigrations = logMigrations;
